==> abiword-2.3.5.tar.bz2: abiword-2.3.5/abiword-plugins/wp/impexp/OpenDocument/xp/OD_SettingsStream_ListenerState.h <==
/* AbiSource
 * 
 * Copyright (C) 2002 Dom Lachowicz <cinamod@hotmail.com>
 * Copyright (C) 2004 Robert Staudinger <robsta@stereolyzer.net>
 * Copyright (C) 2005 Daniel d'Andrada T. de Carvalho
 * <daniel.carvalho@indt.org.br>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

#ifndef _OD_SETTINGSSTREAM_LISTENERSTATE_H_
#define _OD_SETTINGSSTREAM_LISTENERSTATE_H_

// Internal includes
#include "OD_ListenerState.h"


/**
 * Class to handle the settings stream
 */
class OD_SettingsStream_ListenerState : public OD_ListenerState {
    
public:
    
    OD_SettingsStream_ListenerState() : OD_ListenerState("SettingsStream") {}
    
    void startElement (const XML_Char* pName, const XML_Char** ppAtts,
                               OD_ListenerStateAction& rAction) {}
                               
    void endElement (const XML_Char* pName, OD_ListenerStateAction& rAction) {}
                             
    void charData (const XML_Char* pBuffer, int length) {}
};

#endif //_OD_SETTINGSSTREAM_LISTENERSTATE_H_

==> abiword-2.3.6.tar.bz2: abiword-2.3.6/abiword-plugins/wp/impexp/OpenDocument/xp/OD_SettingsStream_ListenerState.h <==
/* AbiSource
 * 
 * Copyright (C) 2002 Dom Lachowicz <cinamod@hotmail.com>
 * Copyright (C) 2004 Robert Staudinger <robsta@stereolyzer.net>
 * Copyright (C) 2005 Daniel d'Andrada T. de Carvalho
 * <daniel.carvalho@indt.org.br>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

#ifndef _OD_SETTINGSSTREAM_LISTENERSTATE_H_
#define _OD_SETTINGSSTREAM_LISTENERSTATE_H_

// Internal includes
#include "OD_ListenerState.h"


/**
 * Class to handle the settings stream
 */
class OD_SettingsStream_ListenerState : public OD_ListenerState {
    
public:
    
    OD_SettingsStream_ListenerState(OD_ElementStack& rElementStack) :
    	OD_ListenerState("SettingsStream", rElementStack) {}
    
    void startElement (const XML_Char* pName, const XML_Char** ppAtts,
                               OD_ListenerStateAction& rAction) {}
                               
    void endElement (const XML_Char* pName, OD_ListenerStateAction& rAction) {}
                             
    void charData (const XML_Char* pBuffer, int length) {}
};

#endif //_OD_SETTINGSSTREAM_LISTENERSTATE_H_
